@@ -6,6 +6,6 @@ urlpatterns = patterns('',
     (r'^papers/(?P<paper>.+)$', views.papers),
     (r'^publications/?$', views.publications, { 'collection' : 'luispedro' }),
     (r'^publications/(?P<collection>.+)$', views.publications),
-    (r'^publications/files/(?P<file>.+)$', 'django.views.static.serve', {'document_root': settings._BASE_DIR + '/../media/publications/files'}),
+    (r'^publications/files/(?P<file>.+)$', 'django.views.static.serve', {'document_root': settings.MEDIA_ROOT + '/publications/files'}),
 )
 
