@@ -2,30 +2,9 @@ from models import Article
 import os
 from os import path
 import yaml
-import settings
-from docutils.core import publish_parts
-from django.utils.encoding import smart_str, force_unicode
-from django.utils.safestring import mark_safe
+from django.conf import settings
 from gitcms.simpletagging.models import tag_for
-
-_precontent = '''\
-**********
-Fake Title
-**********
-+++++++++++++
-Fake Subtitle
-+++++++++++++
-
-'''
-
-
-def preprocess_rst_content(value):
-    # This is adapted from django source
-    value = _precontent + value
-    docutils_settings = getattr(settings, "RESTRUCTUREDTEXT_FILTER_SETTINGS", {})
-    parts = publish_parts(source=smart_str(value), writer_name="html4css1", settings_overrides=docutils_settings)
-    return mark_safe(force_unicode(parts["fragment"]))
-
+from .rest import preprocess_rst_content
 
 def loaddir(directory, clear=False):
     if clear:
